# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'simsapa/assets/ui/library_browser_window.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_LibraryBrowserWindow(object):
    def setupUi(self, LibraryBrowserWindow):
        LibraryBrowserWindow.setObjectName("LibraryBrowserWindow")
        LibraryBrowserWindow.resize(856, 581)
        LibraryBrowserWindow.setBaseSize(QtCore.QSize(800, 600))
        self.central_widget = QtWidgets.QWidget(LibraryBrowserWindow)
        self.central_widget.setObjectName("central_widget")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.central_widget)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.main_layout = QtWidgets.QVBoxLayout()
        self.main_layout.setObjectName("main_layout")
        self.searchbar_layout = QtWidgets.QHBoxLayout()
        self.searchbar_layout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.searchbar_layout.setObjectName("searchbar_layout")
        self.search_input = QtWidgets.QLineEdit(self.central_widget)
        self.search_input.setMinimumSize(QtCore.QSize(0, 35))
        self.search_input.setClearButtonEnabled(True)
        self.search_input.setObjectName("search_input")
        self.searchbar_layout.addWidget(self.search_input)
        self.search_button = QtWidgets.QPushButton(self.central_widget)
        self.search_button.setMinimumSize(QtCore.QSize(0, 40))
        self.search_button.setObjectName("search_button")
        self.searchbar_layout.addWidget(self.search_button)
        self.main_layout.addLayout(self.searchbar_layout)
        self.splitter = QtWidgets.QSplitter(self.central_widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.splitter.sizePolicy().hasHeightForWidth())
        self.splitter.setSizePolicy(sizePolicy)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.verticalLayoutWidget_2 = QtWidgets.QWidget(self.splitter)
        self.verticalLayoutWidget_2.setObjectName("verticalLayoutWidget_2")
        self.documents_layout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_2)
        self.documents_layout.setContentsMargins(0, 0, 0, 0)
        self.documents_layout.setObjectName("documents_layout")
        self.documents_list = QtWidgets.QListView(self.verticalLayoutWidget_2)
        self.documents_list.setObjectName("documents_list")
        self.documents_layout.addWidget(self.documents_list)
        self.verticalLayoutWidget_3 = QtWidgets.QWidget(self.splitter)
        self.verticalLayoutWidget_3.setObjectName("verticalLayoutWidget_3")
        self.info_layout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_3)
        self.info_layout.setContentsMargins(0, 0, 0, 0)
        self.info_layout.setObjectName("info_layout")
        self.doc_cover = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.doc_cover.setMinimumSize(QtCore.QSize(100, 0))
        self.doc_cover.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.doc_cover.setObjectName("doc_cover")
        self.info_layout.addWidget(self.doc_cover)
        self.doc_title = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.doc_title.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.doc_title.setObjectName("doc_title")
        self.info_layout.addWidget(self.doc_title)
        self.doc_author = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.doc_author.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.doc_author.setObjectName("doc_author")
        self.info_layout.addWidget(self.doc_author)
        self.label = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setText("")
        self.label.setObjectName("label")
        self.info_layout.addWidget(self.label)
        self.main_layout.addWidget(self.splitter)
        self.horizontalLayout_2.addLayout(self.main_layout)
        LibraryBrowserWindow.setCentralWidget(self.central_widget)
        self.menubar = QtWidgets.QMenuBar(LibraryBrowserWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 856, 20))
        self.menubar.setObjectName("menubar")
        self.menu_File = QtWidgets.QMenu(self.menubar)
        self.menu_File.setObjectName("menu_File")
        self.menu_Edit = QtWidgets.QMenu(self.menubar)
        self.menu_Edit.setObjectName("menu_Edit")
        self.menu_Windows = QtWidgets.QMenu(self.menubar)
        self.menu_Windows.setObjectName("menu_Windows")
        self.menu_Help = QtWidgets.QMenu(self.menubar)
        self.menu_Help.setObjectName("menu_Help")
        self.menu_Library = QtWidgets.QMenu(self.menubar)
        self.menu_Library.setObjectName("menu_Library")
        LibraryBrowserWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(LibraryBrowserWindow)
        self.statusbar.setObjectName("statusbar")
        LibraryBrowserWindow.setStatusBar(self.statusbar)
        self.toolBar = QtWidgets.QToolBar(LibraryBrowserWindow)
        self.toolBar.setObjectName("toolBar")
        LibraryBrowserWindow.addToolBar(QtCore.Qt.LeftToolBarArea, self.toolBar)
        self.toolBar_2 = QtWidgets.QToolBar(LibraryBrowserWindow)
        self.toolBar_2.setObjectName("toolBar_2")
        LibraryBrowserWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar_2)
        self.action_Copy = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Copy.setObjectName("action_Copy")
        self.action_Paste = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Paste.setObjectName("action_Paste")
        self.action_Quit = QtWidgets.QAction(LibraryBrowserWindow)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/close"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Quit.setIcon(icon)
        self.action_Quit.setObjectName("action_Quit")
        self.action_Sutta_Search = QtWidgets.QAction(LibraryBrowserWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/book"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Sutta_Search.setIcon(icon1)
        self.action_Sutta_Search.setObjectName("action_Sutta_Search")
        self.action_Dictionary_Search = QtWidgets.QAction(LibraryBrowserWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/dictionary"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Dictionary_Search.setIcon(icon2)
        self.action_Dictionary_Search.setObjectName("action_Dictionary_Search")
        self.action_About = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_About.setObjectName("action_About")
        self.action_Website = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Website.setObjectName("action_Website")
        self.action_Close_Window = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Close_Window.setObjectName("action_Close_Window")
        self.action_Open = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Open.setObjectName("action_Open")
        self.action_Document_Reader = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Document_Reader.setObjectName("action_Document_Reader")
        self.action_Add = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Add.setObjectName("action_Add")
        self.action_Remove = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Remove.setObjectName("action_Remove")
        self.action_Open_Selected = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Open_Selected.setObjectName("action_Open_Selected")
        self.action_Library = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Library.setObjectName("action_Library")
        self.action_Notes = QtWidgets.QAction(LibraryBrowserWindow)
        self.action_Notes.setObjectName("action_Notes")
        self.menu_File.addAction(self.action_Open)
        self.menu_File.addAction(self.action_Close_Window)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Quit)
        self.menu_Edit.addAction(self.action_Copy)
        self.menu_Edit.addAction(self.action_Paste)
        self.menu_Windows.addAction(self.action_Sutta_Search)
        self.menu_Windows.addAction(self.action_Dictionary_Search)
        self.menu_Windows.addAction(self.action_Document_Reader)
        self.menu_Windows.addAction(self.action_Library)
        self.menu_Windows.addAction(self.action_Notes)
        self.menu_Help.addAction(self.action_Website)
        self.menu_Help.addAction(self.action_About)
        self.menu_Library.addAction(self.action_Open_Selected)
        self.menu_Library.addAction(self.action_Add)
        self.menu_Library.addAction(self.action_Remove)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Edit.menuAction())
        self.menubar.addAction(self.menu_Windows.menuAction())
        self.menubar.addAction(self.menu_Library.menuAction())
        self.menubar.addAction(self.menu_Help.menuAction())
        self.toolBar.addAction(self.action_Sutta_Search)
        self.toolBar.addAction(self.action_Dictionary_Search)
        self.toolBar_2.addAction(self.action_Open_Selected)
        self.toolBar_2.addAction(self.action_Add)
        self.toolBar_2.addAction(self.action_Remove)

        self.retranslateUi(LibraryBrowserWindow)
        QtCore.QMetaObject.connectSlotsByName(LibraryBrowserWindow)

    def retranslateUi(self, LibraryBrowserWindow):
        _translate = QtCore.QCoreApplication.translate
        LibraryBrowserWindow.setWindowTitle(_translate("LibraryBrowserWindow", "Library - Simsapa"))
        self.search_button.setText(_translate("LibraryBrowserWindow", "Search"))
        self.doc_cover.setText(_translate("LibraryBrowserWindow", "Cover"))
        self.doc_title.setText(_translate("LibraryBrowserWindow", "Title"))
        self.doc_author.setText(_translate("LibraryBrowserWindow", "Author"))
        self.menu_File.setTitle(_translate("LibraryBrowserWindow", "&File"))
        self.menu_Edit.setTitle(_translate("LibraryBrowserWindow", "&Edit"))
        self.menu_Windows.setTitle(_translate("LibraryBrowserWindow", "&Windows"))
        self.menu_Help.setTitle(_translate("LibraryBrowserWindow", "&Help"))
        self.menu_Library.setTitle(_translate("LibraryBrowserWindow", "&Library"))
        self.toolBar.setWindowTitle(_translate("LibraryBrowserWindow", "toolBar"))
        self.toolBar_2.setWindowTitle(_translate("LibraryBrowserWindow", "toolBar_2"))
        self.action_Copy.setText(_translate("LibraryBrowserWindow", "&Copy"))
        self.action_Paste.setText(_translate("LibraryBrowserWindow", "&Paste"))
        self.action_Quit.setText(_translate("LibraryBrowserWindow", "&Quit"))
        self.action_Quit.setShortcut(_translate("LibraryBrowserWindow", "Ctrl+Q"))
        self.action_Sutta_Search.setText(_translate("LibraryBrowserWindow", "&Sutta Search"))
        self.action_Sutta_Search.setShortcut(_translate("LibraryBrowserWindow", "F5"))
        self.action_Dictionary_Search.setText(_translate("LibraryBrowserWindow", "&Dictionary Search"))
        self.action_Dictionary_Search.setShortcut(_translate("LibraryBrowserWindow", "F6"))
        self.action_About.setText(_translate("LibraryBrowserWindow", "&About"))
        self.action_Website.setText(_translate("LibraryBrowserWindow", "&Website"))
        self.action_Close_Window.setText(_translate("LibraryBrowserWindow", "&Close Window"))
        self.action_Open.setText(_translate("LibraryBrowserWindow", "&Open..."))
        self.action_Open.setShortcut(_translate("LibraryBrowserWindow", "Ctrl+O"))
        self.action_Document_Reader.setText(_translate("LibraryBrowserWindow", "D&ocument Reader"))
        self.action_Document_Reader.setToolTip(_translate("LibraryBrowserWindow", "Document Reader"))
        self.action_Document_Reader.setShortcut(_translate("LibraryBrowserWindow", "F7"))
        self.action_Add.setText(_translate("LibraryBrowserWindow", "&Add..."))
        self.action_Remove.setText(_translate("LibraryBrowserWindow", "&Remove"))
        self.action_Remove.setShortcut(_translate("LibraryBrowserWindow", "Del"))
        self.action_Open_Selected.setText(_translate("LibraryBrowserWindow", "&Open Selected"))
        self.action_Library.setText(_translate("LibraryBrowserWindow", "&Library"))
        self.action_Library.setShortcut(_translate("LibraryBrowserWindow", "F8"))
        self.action_Notes.setText(_translate("LibraryBrowserWindow", "&Notes"))
        self.action_Notes.setToolTip(_translate("LibraryBrowserWindow", "Notes"))
        self.action_Notes.setShortcut(_translate("LibraryBrowserWindow", "F9"))
from simsapa.assets import icons_rc
